package com.ruoyi.web.controller.dhc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.dhc.domain.DhcAreaCountry;
import com.ruoyi.dhc.service.IDhcAreaCountryService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * 区域国家Controller
 * 
 * @author ruoyi
 * @date 2025-03-13
 */
@Api(tags = "区域国家管理")
@RestController
@RequestMapping("/dhc/dhcAreaCountry")
public class DhcAreaCountryController extends BaseController
{
    @Autowired
    private IDhcAreaCountryService dhcAreaCountryService;

    /**
     * 查询区域国家列表
     */
    @ApiOperation("查询区域国家列表")
    @PreAuthorize("@ss.hasPermi('dhc:country:list')")
    @GetMapping("/list")
    public TableDataInfo list(DhcAreaCountry dhcAreaCountry)
    {
        startPage();
        List<DhcAreaCountry> list = dhcAreaCountryService.selectDhcAreaCountryList(dhcAreaCountry);
        return getDataTable(list);
    }

    /**
     * 导出区域国家列表
     */
    @ApiOperation("导出区域国家列表")
    @PreAuthorize("@ss.hasPermi('dhc:country:export')")
    @Log(title = "区域国家", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DhcAreaCountry dhcAreaCountry)
    {
        List<DhcAreaCountry> list = dhcAreaCountryService.selectDhcAreaCountryList(dhcAreaCountry);
        ExcelUtil<DhcAreaCountry> util = new ExcelUtil<DhcAreaCountry>(DhcAreaCountry.class);
        util.exportExcel(response, list, "区域国家数据");
    }

    /**
     * 获取区域国家详细信息
     */
    @ApiOperation("获取区域国家详细信息")
    @PreAuthorize("@ss.hasPermi('dhc:country:query')")
    @GetMapping(value = "/{countryId}")
    public AjaxResult getInfo(@PathVariable("countryId") Long countryId)
    {
        return success(dhcAreaCountryService.selectDhcAreaCountryByCountryId(countryId));
    }

    /**
     * 新增区域国家
     */
    @ApiOperation("新增区域国家")
    @PreAuthorize("@ss.hasPermi('dhc:country:add')")
    @Log(title = "区域国家", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DhcAreaCountry dhcAreaCountry)
    {
        return toAjax(dhcAreaCountryService.insertDhcAreaCountry(dhcAreaCountry));
    }

    /**
     * 修改区域国家
     */
    @ApiOperation("修改区域国家")
    @PreAuthorize("@ss.hasPermi('dhc:country:edit')")
    @Log(title = "区域国家", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DhcAreaCountry dhcAreaCountry)
    {
        return toAjax(dhcAreaCountryService.updateDhcAreaCountry(dhcAreaCountry));
    }

    /**
     * 删除区域国家
     */
    @ApiOperation("删除区域国家")
    @PreAuthorize("@ss.hasPermi('dhc:country:remove')")
    @Log(title = "区域国家", businessType = BusinessType.DELETE)
	@DeleteMapping("/{countryIds}")
    public AjaxResult remove(@PathVariable Long[] countryIds)
    {
        return toAjax(dhcAreaCountryService.deleteDhcAreaCountryByCountryIds(countryIds));
    }
}
