package com.ruoyi.web.controller.dhc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.dhc.domain.DhcCountry;
import com.ruoyi.dhc.service.IDhcCountryService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * 国家Controller
 *
 * @author ruoyi
 * @date 2025-03-12
 */
@Api(tags = "国家管理")
@RestController
@RequestMapping("/dhc/dhcCountry")
public class DhcCountryController extends BaseController
{
    @Autowired
    private IDhcCountryService dhcCountryService;

    /**
     * 查询国家列表
     */
    @ApiOperation("查询国家列表")
    @PreAuthorize("@ss.hasPermi('dhc:country:list')")
    @GetMapping("/list")
    public TableDataInfo list(DhcCountry dhcCountry)
    {
        startPage();
        List<DhcCountry> list = dhcCountryService.selectDhcCountryList(dhcCountry);
        return getDataTable(list);
    }

    /**
     * 导出国家列表
     */
    @ApiOperation("导出国家列表")
    @PreAuthorize("@ss.hasPermi('dhc:country:export')")
    @Log(title = "国家", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DhcCountry dhcCountry)
    {
        List<DhcCountry> list = dhcCountryService.selectDhcCountryList(dhcCountry);
        ExcelUtil<DhcCountry> util = new ExcelUtil<DhcCountry>(DhcCountry.class);
        util.exportExcel(response, list, "国家数据");
    }

    /**
     * 获取国家详细信息
     */
    @ApiOperation("获取国家详细信息")
    @PreAuthorize("@ss.hasPermi('dhc:country:query')")
    @GetMapping(value = "/{countryId}")
    public AjaxResult getInfo(@PathVariable("countryId") Long countryId)
    {
        return success(dhcCountryService.selectDhcCountryByCountryId(countryId));
    }

    /**
     * 新增国家
     */
    @ApiOperation("新增国家")
    @PreAuthorize("@ss.hasPermi('dhc:country:add')")
    @Log(title = "国家", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DhcCountry dhcCountry)
    {
        return toAjax(dhcCountryService.insertDhcCountry(dhcCountry));
    }

    /**
     * 修改国家
     */
    @ApiOperation("修改国家")
    @PreAuthorize("@ss.hasPermi('dhc:country:edit')")
    @Log(title = "国家", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DhcCountry dhcCountry)
    {
        return toAjax(dhcCountryService.updateDhcCountry(dhcCountry));
    }

    /**
     * 删除国家
     */
    @ApiOperation("删除国家")
    @PreAuthorize("@ss.hasPermi('dhc:country:remove')")
    @Log(title = "国家", businessType = BusinessType.DELETE)
    @DeleteMapping("/{countryIds}")
    public AjaxResult remove(@PathVariable Long[] countryIds)
    {
        return toAjax(dhcCountryService.deleteDhcCountryByCountryIds(countryIds));
    }
}

