package com.ruoyi.web.controller.dhc.cfg;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.dhc.domain.CfgCharConfig;
import com.ruoyi.dhc.service.ICfgCharConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * 黑电协议基础数据（特性）Controller
 * 
 * @author ruoyi
 * @date 2025-03-10
 */
@Api(tags = "黑电协议基础数据（特性）管理")
@RestController
@RequestMapping("/dhc/cfgCharConfig")
public class CfgCharConfigController extends BaseController
{
    @Autowired
    private ICfgCharConfigService cfgCharConfigService;

    /**
     * 查询黑电协议基础数据（特性）列表
     */
    @ApiOperation("查询黑电协议基础数据（特性）列表")
    @PreAuthorize("@ss.hasPermi('dhc:config:list')")
    @GetMapping("/list")
    public TableDataInfo list(CfgCharConfig cfgCharConfig)
    {
        startPage();
        List<CfgCharConfig> list = cfgCharConfigService.selectCfgCharConfigList(cfgCharConfig);
        return getDataTable(list);
    }

    /**
     * 导出黑电协议基础数据（特性）列表
     */
    @ApiOperation("导出黑电协议基础数据（特性）列表")
    @PreAuthorize("@ss.hasPermi('dhc:config:export')")
    @Log(title = "黑电协议基础数据（特性）", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CfgCharConfig cfgCharConfig)
    {
        List<CfgCharConfig> list = cfgCharConfigService.selectCfgCharConfigList(cfgCharConfig);
        ExcelUtil<CfgCharConfig> util = new ExcelUtil<CfgCharConfig>(CfgCharConfig.class);
        util.exportExcel(response, list, "黑电协议基础数据（特性）数据");
    }

    /**
     * 获取黑电协议基础数据（特性）详细信息
     */
    @ApiOperation("获取黑电协议基础数据（特性）详细信息")
    @PreAuthorize("@ss.hasPermi('dhc:config:query')")
    @GetMapping(value = "/{charId}")
    public AjaxResult getInfo(@PathVariable("charId") Long charId)
    {
        return success(cfgCharConfigService.selectCfgCharConfigByCharId(charId));
    }

    /**
     * 新增黑电协议基础数据（特性）
     */
    @ApiOperation("新增黑电协议基础数据（特性）")
    @PreAuthorize("@ss.hasPermi('dhc:config:add')")
    @Log(title = "黑电协议基础数据（特性）", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CfgCharConfig cfgCharConfig)
    {
        return toAjax(cfgCharConfigService.insertCfgCharConfig(cfgCharConfig));
    }

    /**
     * 修改黑电协议基础数据（特性）
     */
    @ApiOperation("修改黑电协议基础数据（特性）")
    @PreAuthorize("@ss.hasPermi('dhc:config:edit')")
    @Log(title = "黑电协议基础数据（特性）", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CfgCharConfig cfgCharConfig)
    {
        return toAjax(cfgCharConfigService.updateCfgCharConfig(cfgCharConfig));
    }

    /**
     * 删除黑电协议基础数据（特性）
     */
    @ApiOperation("删除黑电协议基础数据（特性）")
    @PreAuthorize("@ss.hasPermi('dhc:config:remove')")
    @Log(title = "黑电协议基础数据（特性）", businessType = BusinessType.DELETE)
	@DeleteMapping("/{charIds}")
    public AjaxResult remove(@PathVariable Long[] charIds)
    {
        return toAjax(cfgCharConfigService.deleteCfgCharConfigByCharIds(charIds));
    }
}
