package com.ruoyi.dhc.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.dhc.mapper.DhcAreaCountryMapper;
import com.ruoyi.dhc.domain.DhcAreaCountry;
import com.ruoyi.dhc.service.IDhcAreaCountryService;

/**
 * 区域国家Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-13
 */
@Service
public class DhcAreaCountryServiceImpl implements IDhcAreaCountryService 
{
    @Autowired
    private DhcAreaCountryMapper dhcAreaCountryMapper;

    /**
     * 查询区域国家
     * 
     * @param countryId 区域国家主键
     * @return 区域国家
     */
    @Override
    public DhcAreaCountry selectDhcAreaCountryByCountryId(Long countryId)
    {
        return dhcAreaCountryMapper.selectDhcAreaCountryByCountryId(countryId);
    }

    /**
     * 查询区域国家列表
     * 
     * @param dhcAreaCountry 区域国家
     * @return 区域国家
     */
    @Override
    public List<DhcAreaCountry> selectDhcAreaCountryList(DhcAreaCountry dhcAreaCountry)
    {
        return dhcAreaCountryMapper.selectDhcAreaCountryList(dhcAreaCountry);
    }

    /**
     * 新增区域国家
     * 
     * @param dhcAreaCountry 区域国家
     * @return 结果
     */
    @Override
    public int insertDhcAreaCountry(DhcAreaCountry dhcAreaCountry)
    {
        dhcAreaCountry.setCreateTime(DateUtils.getNowDate());
        return dhcAreaCountryMapper.insertDhcAreaCountry(dhcAreaCountry);
    }

    /**
     * 修改区域国家
     * 
     * @param dhcAreaCountry 区域国家
     * @return 结果
     */
    @Override
    public int updateDhcAreaCountry(DhcAreaCountry dhcAreaCountry)
    {
        dhcAreaCountry.setUpdateTime(DateUtils.getNowDate());
        return dhcAreaCountryMapper.updateDhcAreaCountry(dhcAreaCountry);
    }

    /**
     * 批量删除区域国家
     * 
     * @param countryIds 需要删除的区域国家主键
     * @return 结果
     */
    @Override
    public int deleteDhcAreaCountryByCountryIds(Long[] countryIds)
    {
        return dhcAreaCountryMapper.deleteDhcAreaCountryByCountryIds(countryIds);
    }

    /**
     * 删除区域国家信息
     * 
     * @param countryId 区域国家主键
     * @return 结果
     */
    @Override
    public int deleteDhcAreaCountryByCountryId(Long countryId)
    {
        return dhcAreaCountryMapper.deleteDhcAreaCountryByCountryId(countryId);
    }
}
